import React, { Component } from 'react';
import { RowComponent, MoveComponent } from './index';
import { initConfigRow } from '../../configs/editorBox';
import { randomNumber } from '../../helper';

const Redrag = __REUSEFORM_COMPONENT__.redrag;

export default class FieldsComponent extends Component {
  render() {
    const {
      allRows,
      updateRows,
      selectedData,
      selectedField,
      selectedPostType,
      parentId,
    } = this.props;
    const addRow = () => {
      const newAllrows = selectedData[selectedPostType];
      const newRow = {
        id: `row-${randomNumber()}`,
        type: 'row',
        selectedPostType,
        ...initConfigRow,
      };
      if (parentId) {
        newRow.parentId = parentId;
        const index = newAllrows.findIndex(row => row.id === parentId);
        let rows = newAllrows[index].rows ? newAllrows[index].rows : [];
        rows = [...rows, newRow];
        newAllrows[index].rows = rows;
      } else {
        newAllrows.push(newRow);
      }
      selectedData[selectedPostType] = newAllrows;
      updateRows({ selectedData });
    };
    const addSet = () => {
      allRows.push({
        id: `set-${randomNumber()}`,
        type: 'set',
        title: '',
        rows: [],
        selectedPostType,
      });
      selectedData[selectedPostType] = allRows;
      updateRows({ selectedData });
    };
    const redragOptions = {
      // ...this.props,
      selectedData,
      selectedField,
      selectedPostType,
      parentId,
      updateRows,
      dragItems: allRows,
      componentName: RowComponent,
      moveComponent: MoveComponent,
      componentStyle: {},
      item: { id: selectedPostType },
      styles: {},
      className: 'scwpFormFieldsWrapper',
      singleItemClassName: 'scwpFormSingleFields',
      updateData: (item, data) => {
        if (!item.parentId) {
          if (parentId) {
            const newData = [];
            selectedData[selectedPostType].forEach((row) => {
              if (row.id === parentId) {
                row.rows = data;
              }
              newData.push(row);
            });
            selectedData[selectedPostType] = newData;
          } else {
            selectedData[selectedPostType] = data;
          }
          updateRows({ selectedData });
        }
      },
      editField: (data) => {
        updateRows({ selectedField: data });
      },
      deleteField: (data) => {
        if (parentId) {
          const index = selectedData[selectedPostType].findIndex(row => row.id === data.parentId);
          const rows = selectedData[selectedPostType][index].rows;
          const childIndex = rows.findIndex(row => row.id === data.id);
          rows.splice(childIndex, 1);
          selectedData[selectedPostType][index].rows = rows;
          const newSelectedField =
            selectedField && selectedField.id !== data.id ? selectedField : undefined;
          updateRows({ selectedData, selectedField: newSelectedField });
        } else {
          const index = allRows.findIndex(row => row.id === data.id);
          allRows.splice(index, 1);
          selectedData[selectedPostType] = allRows;
          const newSelectedField =
            selectedField && selectedField.id !== data.id && selectedField.parentId !== data.id
              ? selectedField
              : undefined;
          updateRows({ selectedData, selectedField: newSelectedField });
        }
      },
    };
    return (
      <div>
        {allRows && allRows.length > 0 ? <Redrag {...redragOptions} /> : ''}
        <div className="alikePol">
          <button type="button" onClick={addRow}>
            Add Row
          </button>
          {parentId ? (
            ''
          ) : (
            <button type="button" className="scwpAddBtn scwpAddFormBundle" onClick={addSet}>
              Add Set
            </button>
          )}
        </div>
      </div>
    );
  }
}
