import React from 'react';
import swal from 'sweetalert';
import { configRow, configSet, conditions } from '../../configs/editorBox';
import { prettifyCamelCase, termKeyNames } from '../../helper';

const ReuseForm = __REUSEFORM__;
const reuseformData = {};

function saveData(props) {
  const { selectedField, updateField } = props;
  const newData = reuseformData[selectedField.id];
  let formError = false;
  if (selectedField.type === 'row') {
    const selectedPost = newData.selectedPost ? newData.selectedPost.split(',') : [];
    if (selectedPost.length > 1) {
      if (!newData.title) {
        newData.title = termKeyNames[selectedPost[1]]
          ? termKeyNames[selectedPost[1]]
          : prettifyCamelCase(selectedPost[1]);
      }
    } else {
      newData.title = '';
      swal('No Post Type!', 'Please select a post type.', 'warning');
      formError = true;
    }
    if (newData.displayType === 'custom' && !newData.customId) {
      swal('No Custom Id!', 'Please set a Id for Custom display.', 'warning');
      formError = true;
    }
  } else if (!newData.title) {
    swal('No Title!', 'Please set Title.', 'warning');
    formError = true;
  }
  if (!formError) {
    swal('SAVED!', 'Data saved successfully.', 'success');
    updateField(newData);
  }
}
export default function editRowComponent(props) {
  const { selectedField, selectedData, options, selectedPostType } = props;
  if (
    !selectedField ||
    !selectedData[selectedPostType] ||
    selectedField.selectedPostType !== selectedPostType
  ) {
    return '';
  }
  const fields = selectedField.type === 'set' ? configSet : configRow;
  fields[0].options = options;
  const reuseOption = {
    reuseFormId: `row-${selectedField.id}`,
    fields,
    conditions,
    getUpdatedFields: (data) => {
      reuseformData[selectedField.id] = data;
    },
    preValue: selectedField,
    errorMessages: {},
  };
  return (
    <div>
      <div className="reuseFormWrapper">
        <ReuseForm {...reuseOption} />
      </div>
      <button className="alike-save-btn" type="button" onClick={() => saveData(props)}>
        SAVE
      </button>
    </div>
  );
}
