import React, { Component } from 'react';
import { connect } from 'react-redux';
import clone from 'clone';
import { setSelectedData } from '../reducers/postTypeReducer';
import { SettingsPanel, FieldsComponent } from '../components/editorBox/index';
import './editorBoxRender.css';
class RenderEditorBox extends Component {
  constructor(props) {
    super(props);
    this.updateRows = this.updateRows.bind(this);
    this.updateField = this.updateField.bind(this);
    this.reuseformData = undefined;
    this.state = {
      selectedData: this.props.selectedData,
      selectedField: undefined,
    };
  }
  updateRows(newData) {
    this.setState({ ...clone(newData) });
    if (newData.selectedData) {
      this.props.setSelectedData(newData.selectedData);
    }
  }
  updateField(newData) {
    const { selectedField, selectedData } = this.state;
    const { selectedPostType } = this.props;
    if (selectedField.parentId) {
      const index = selectedData[selectedPostType].findIndex(
        row => row.id === selectedField.parentId,
      );
      const childIndex = selectedData[selectedPostType][index].rows.findIndex(
        row => row.id === selectedField.id,
      );
      selectedData[selectedPostType][index].rows[childIndex] = {
        ...selectedData[selectedPostType][index].rows[childIndex],
        ...newData,
      };
    } else {
      const index = selectedData[selectedPostType].findIndex(row => row.id === selectedField.id);
      selectedData[selectedPostType][index] = {
        ...selectedData[selectedPostType][index],
        ...newData,
      };
    }
    this.props.setSelectedData(selectedData);
  }
  render() {
    const { selectedPostType, options } = this.props;
    const { selectedData, selectedField } = this.state;
    const allRows = selectedData[selectedPostType] ? selectedData[selectedPostType] : [];
    if (!selectedPostType) {
      return <h2> please select a post type </h2>;
    }
    const editRowComponentProps = {
      selectedField,
      selectedData,
      options,
      selectedPostType,
      updateField: this.updateField,
    };
    const fieldsComponentProp = {
      selectedPostType,
      selectedData,
      selectedField,
      allRows,
      updateRows: this.updateRows,
    };
    return (
      <div className="renderBox">
        <div style={{ width: '100%', display: 'inline' }}>
          <h3>
            {selectedPostType}
          </h3>
        </div>
        <div style={{ width: '100%', display: 'inline' }}>
          <div style={{ display: 'flex' }}>
            <div style={{ width: '40%', display: 'inline' }}>
              <FieldsComponent {...fieldsComponentProp} />
            </div>
            <div style={{ width: '60%' }}>
              {SettingsPanel(editRowComponentProps)}
            </div>
          </div>
        </div>
      </div>
    );
  }
}

function mapStateToProps(state) {
  const { selectedPostType, selectedData, initialData } = state.PostTypeReducer.toJS();
  const options = selectedPostType ? initialData[selectedPostType] : [];
  if (selectedPostType && !selectedData[selectedPostType]) {
    selectedData[selectedPostType] = [];
  }

  return {
    selectedPostType,
    selectedData,
    options,
  };
}

export default connect(mapStateToProps, {
  setSelectedData,
})(RenderEditorBox);
