import React, { Component } from 'react';
import { connect } from 'react-redux';
import swal from 'sweetalert';
import { addPostTypes, postTypeSelectAction, deletePostTypes } from '../reducers/postTypeReducer';
import {  prettifyCamelCase } from '../helper';
import AddPostModal from './addPostModal';

function AddBox(props) {
  const options = {
    href: '#',
    onClick: (event) => {
      event.preventDefault();
      props.openModal();
    },
  };
  return (<div className="addBoxWrapper boxWrapper">
    <a {...options}> </a>
  </div>);
}

class RenderPostTypes extends Component {
  constructor(props) {
    super(props);
    this.openModal = this.openModal.bind(this);
    this.closeModal = this.closeModal.bind(this);
    this.addPostType = this.addPostType.bind(this);
    this.handleBoxDelete = this.handleBoxDelete.bind(this);
    this.state = { modalIsOpen: false };
  }
  openModal() {
    this.setState({ modalIsOpen: true });
  }
  closeModal() {
    this.setState({ modalIsOpen: false });
  }
  addPostType(value) {
    this.props.addPostTypes(value);
    this.closeModal();
  }
  handleBoxDelete(item, event) {
    event.preventDefault();
    swal({
      title: 'Are you sure?',
      text: 'You will not be able to recover this imaginary file!',
      type: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#DD6B55',
      confirmButtonText: 'Yes, delete it!',
      closeOnConfirm: false,
      html: false,
    }, () => {
      this.props.deletePostTypes(item);
      swal('Deleted!', 'Your imaginary file has been deleted.', 'success');
    });
  }
  handleBoxSelection(postType, event) {
    event.preventDefault();
    this.props.postTypeSelectAction(postType);
  }
  render() {
    const { editablePostType, postTypes } = this.props;
    const showPostTypes = postTypes.map((item, index) => {
      const activeClass = editablePostType === item ? 'boxWrapper boxActive' : 'boxWrapper';
      return (<div key={index} className={activeClass}>
        <button type="button" className="boxCloser" onClick={this.handleBoxDelete.bind(this, item)}></button>
        <button className="boxItems" onClick={this.handleBoxSelection.bind(this, item)}>
          {prettifyCamelCase(item)}
        </button>
      </div>);
    });
    const AddPostModalProps = {
      modalIsOpen: this.state.modalIsOpen,
      closeModal: this.closeModal,
      addPostType: this.addPostType,
      postTypes,
    };
    return (<div className="postTypeWrapper">
      {showPostTypes}
      <AddBox openModal={this.openModal} />
      <AddPostModal {...AddPostModalProps} />
    </div>);
  }
}
function mapStateToProps(state) {
  const { postTypes } = state.PostTypeReducer.toJS();
  return {
    postTypes,
  };
}

export default connect(mapStateToProps, {
  postTypeSelectAction,
  addPostTypes,
  deletePostTypes,
})(RenderPostTypes);
