import { Map } from 'immutable';
import { http, createOptions } from '../helper';

const initState = new Map({
  postTypes: ALIKE_DATA.postTypes ? ALIKE_DATA.postTypes : [],
  initialData: ALIKE_DATA.initialData ? createOptions(ALIKE_DATA.initialData) : {},
  selectedData: ALIKE_DATA.selectedData && ALIKE_DATA.selectedData !== '1' ? ALIKE_DATA.selectedData : {},
  selectedPostType: undefined,
});
const requestData = {
  nonce: ALIKE_ADMIN.builder_nonce,
};
export default function PostTypeReducer(state = initState, action) {
  switch (action.type) {
    case 'ADD_POSTTYPES':
      return state.set('postTypes', [...action.postTypes])
      .set('initialData', createOptions(action.initialData));
    case 'DELETE_POSTTYPES':
      return state.set('postTypes', [...action.postTypes])
        .set('selectedPostType', action.selectedPostType)
        .set('selectedData', action.selectedData);
    case 'SELECTED_POST_TYPES':
      return state.set('selectedPostType', action.selectedPostType);
    case 'SELECT_DATA':
      return state.set('selectedData', { ...action.selectedData });
    default:
      return state;
  }
}

export function addPostTypes(newPost) {
  return (dispatch, getState) => {
    const postTypes = [...getState().PostTypeReducer.get('postTypes'), newPost];
    requestData.postTypes = postTypes;
    requestData.action = ALIKE_ADMIN.alike_save_post_types;
    http.post(requestData).end((err, res) => {
      if (res) {
        const alikeData = JSON.parse(res.text);
        dispatch({
          type: 'ADD_POSTTYPES',
          postTypes,
          initialData: alikeData.initialData,
        });
      }
    });
  };
}
export function deletePostTypes(newPost) {
  return (dispatch, getState) => {
    const postTypes = getState().PostTypeReducer.get('postTypes');
    const SelectedPostType = getState().PostTypeReducer.get('selectedPostType');
    const oldSelectedData = getState().PostTypeReducer.get('selectedData');
    const selectedPostType = SelectedPostType === newPost ? undefined : SelectedPostType;
    const selectedData = {};
    const index = postTypes.findIndex(postType => postType === newPost);
    postTypes.splice(index, 1);
    postTypes.forEach((post) => {
      if (oldSelectedData[post]) {
        selectedData[post] = oldSelectedData[post];
      }
    });
    requestData.postTypes = postTypes;
    requestData.action = ALIKE_ADMIN.alike_save_post_types;
    http.post(requestData).end((err, res) => {
      if (res) {
        requestData.selectedData = selectedData;
        requestData.action = ALIKE_ADMIN.alike_get_post_data;
        http.post(requestData).end();
        dispatch({
          type: 'DELETE_POSTTYPES',
          postTypes,
          selectedPostType,
          selectedData,
        });
      }
    });
  };
}
export function postTypeSelectAction(selectedPostType) {
  return ({
    type: 'SELECTED_POST_TYPES',
    selectedPostType,
  });
}
export function setSelectedData(selectedData) {
  requestData.selectedData = selectedData;
  requestData.action = ALIKE_ADMIN.alike_get_post_data;
  http.post(requestData).end();
  return ({
    type: 'SELECT_DATA',
    selectedData,
  });
}
