/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';
import { useState, useEffect } from '@wordpress/element';
import apiFetch from '@wordpress/api-fetch';
import {TextControl, RadioControl, PanelBody } from '@wordpress/components';
import { InspectorControls } from '@wordpress/block-editor';


/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, InnerBlocks } from '@wordpress/block-editor';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';
import './style.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit({
	attributes,
	setAttributes,
	noticeOperations,
	noticeUI,
	isSelected,
}) {
	const [ error, setError ]       = useState( null );
    const [ options, setOptions ]       = useState( [] );
    const [ mypost, setPost ]       = useState( [] );
    const [ isLoaded, setIsLoaded ] = useState( false );
	const { 
		data_type, 
		data_value, 
		custom_title, 
		custom_height, 
		display_type,
		custom_scrollbar,
		link_target,
		link_referral,
		button_text,
		link_button_class
	  } = attributes;

    useEffect( () => {
        apiFetch( { path: `alike/v1/data?options=${data_type}`} ).then(
            ( result ) => {
                setIsLoaded( true );
                setPost( result );
            },
            ( error ) => {
                setIsLoaded( true );
                setError( error );
            }
        );
    }, [options] );
	
	return (
		<>
			<InspectorControls>
				<PanelBody>
					<RadioControl
						label="Display Type"
						selected={ display_type }
						options={ [
							{ label: 'Simple', value: 'simple' },
							{ label: 'Rating', value: 'rating' },
							{ label: 'Boolean', value: 'boolean' },
							{ label: 'WooCommerce Price', value: 'price' },
							{ label: 'Hiperlink', value: 'hyperlink' },
						] }
						onChange={ e => setAttributes( {display_type: e} ) }
					/>
					<RadioControl
						label="Enable custom scroll bar"
						selected={ custom_scrollbar }
						options={ [
							{ label: 'Enable', value: 'enable' },
							{ label: 'Disable', value: 'disable' },
						] }
						onChange={ e => setAttributes( {custom_scrollbar: e} ) }
					/>
					{display_type == 'hyperlink' && (
				    <div>
						<div>
							<RadioControl
							label="ENTER TARGET"
							selected={ link_target }
							options={ [
								{ label: 'Self', value: '_self' },
								{ label: 'Blank', value: '_blank' },
							] }
							onChange={ e => setAttributes( {link_target: e} ) }
							/>
						</div>
						<div>
						<TextControl
						label="ENTER THE HYPER LINK REFERRAL URL"
						value={ link_referral }
						onChange={ e => setAttributes( {link_referral: e} ) }
						/>
						</div>
						<div>
						<TextControl
						label="ENTER BUTTON TEXT TO SHOW"
						value={ button_text }
						onChange={ e => setAttributes( {button_text: e} ) }
						/>
						</div>
						<div>
						<TextControl
						label="ENTER LINK BUTTON CLASS TO ADD"
						value={ link_button_class }
						onChange={ e => setAttributes( {link_button_class: e} ) }
						/>
						</div>
					</div>		
					
					
					)

					}
				</PanelBody>
			</InspectorControls>

		<div { ...useBlockProps() }>
			{isSelected}
			{/* <InnerBlocks allowedBlocks={['alike-block/compare-row']} /> */}
			<div>
			 {isSelected && (
				<select onChange={e => setAttributes({data_type: e.target.value})} value={data_type} >
					<option value={'meta_keys'}>Meta Keys</option>
					<option value={'taxonomy_keys'}>Taxonomy Keys</option>
					<option value={'meta_keys'}>Term Keys</option>
					<option value={'post_keys'}>Post keys</option>
				</select>
			 )}
			   { isLoaded && (
				<select onChange={e => setAttributes({data_value: e.target.value})} value={data_value}>
				{
				mypost.map((item, i) => {
					return (<option value={item}>{item.replace("_", " ")}</option>)
				})}
				</select>
				)}
				{
					<TextControl
					label="Custom Title"
					value={ custom_title }
					onChange={ e => setAttributes( {custom_title: e} ) }
				   />
				
				}
				{
					<TextControl
					label="Custom Hight"
					value={ custom_height }
					onChange={ e => setAttributes( {custom_height: e} ) }
				   />
				
				}
			</div>
		</div>
		</>
	);
}
